<?

/*
	tGuiPP_MainFrameSet
	tGuiPP_FrameTop
	tGuiPP_FrameMain
	tGuiPP_FrameHelp
 */
 
// in index.php
class tGuiPP_MainFrameSet {
	var $l_product_name = 'Parallels Confixx';	

	var $head_icon_id  = ''; 
	var $head_text = ''; 
	var $content_url   = '';
	var $menu_url = '';

	var $mcServerID = '';

	function tGuiPP_MainFrameSet($default_node = NULL) {

		global $server_id, $ServerID;

		if ($default_node === NULL) {
			// properties of default content
			$this->head_icon_id  = "overview"; 
			$this->head_text = ltext("m_overview"); 
			$this->content_url   = "allgemein_start.php";
		} else {
			$this->head_icon_id  = $default_node->getName(); 
			$this->head_text = $default_node->getText(); 
			$this->content_url   = $default_node->getContentUrl();
		}
		
		$this->menu_url = 'ver_pp_frame_left_nav_tree.php';

		if( $server_id ){
			$this->ServerID( $server_id );
		}else{
			$this->ServerID( $ServerID );
		}

	}

	function &ServerID( $pcSID = NULL ){
		if( is_string( $pcSID ) ){
			$this->mcServerID = $pcSID;
		}
		return $this->mcServerID;
	}

	function set_menu_url($url)
	{
		$this->menu_url = $url;	
	}
	
	/////////////////////////////////////////
	
	function draw() {
		global $confixx_skin_dir;
		global $lang_html_charset;
		
		$frame_main_args = "?content_url=$this->content_url";
		$frame_top_args  = "?head_id=$this->head_icon_id&&head_text=$this->head_text";
		
// ********************************************* html ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
<html>
<head>
<title><?=$this->l_product_name?></title>
<meta http-equiv="Content-Type" content="text/html; charset=<?=$lang_html_charset?>" />
<script language="javascript">
<!--
function setScrollInIE () {
	var navL = self.leftFrame.document.getElementById ('navArea');
	self.leftFrame.document.body.scroll = (navL.clientHeight > self.leftFrame.document.documentElement.clientHeight || navL.clientWidth > self.leftFrame.document.documentElement.clientWidth) ? 'yes' : 'no';
}
ieAddScroll = '';
ieAddResize = '';
isIEdoctype = navigator.appName == 'Microsoft Internet Explorer' && document.documentElement && navigator.userAgent.indexOf ('Opera') == -1;
if (isIEdoctype) {
	ieAddScroll = ' scrolling="no"';
	ieAddResize = ' onresize="setScrollInIE();"';
}

 function openHeadMenuItem (content_url, help_head_key, help_text_key ) {
	 var cnt = parent.parent.contentFrame;
	 if(cnt){
		var url = 'ver_pp_frame_main.php?content_url='+content_url;
		if(help_head_key){
			url += '&help_head_key=' + help_head_key;
		}
		if(help_text_key){
			url += '&help_text_key=' + help_text_key;
		}
		if(cnt.frames['mainFrame']){

			cnt.frames['mainFrame'].location.href = content_url;
			
			if(cnt.frames['helpFrame']){

				var help_url = 'ver_pp_frame_help.php?help_head_key=' +
					help_head_key + '&help_text_key=' + help_text_key;

				cnt.frames['helpFrame'].location.href = help_url;
			}

		}else{
			cnt.location.href = url;
		}
	}

	//	if (parent.parent.mainFrame) {
	//		alert( 'reload mainFrame' );
	//	    parent.parent.mainFrame.location.href = content_url+'&help_url='+help_url;
	//	}
	return false;
}

//var _c = new Array;	// context help messages

//_c['l_ttsquslist_name'] = 'Context help.';

var context = '';
var helpPerm = true;

function mouse_move(context)
{
	if(!top.helpPerm)
		return false;
	top.SetConHelp(context)
}

function SetContext(context)
{
	if (context)
		top.context = context;
	top.SetConHelp();
	return false;
}
// BrowserCheck Object
function BrowserCheck()
{
        var b = navigator.appName
        if (b=='Netscape') this.b = 'ns'
        else if (b=='Microsoft Internet Explorer') this.b = 'ie'
        else this.b = b
        this.version = navigator.appVersion
        this.v = parseInt(this.version)
        this.ns = (this.b=='ns' && this.v>=4)
        this.ns4 = (this.b=='ns' && this.v==4)
        this.ns5 = (this.b=='ns' && this.v==5)
        this.ie = (this.b=='ie' && this.v>=4)
        this.ie4 = (this.version.indexOf('MSIE 4')>0)
        this.ie5 = (this.version.indexOf('MSIE 5')>0)
        this.ie55 = (this.version.indexOf('MSIE 5.5')>0)
        this.min = (this.ns||this.ie)
}

is = new BrowserCheck()

function SetConHelp(conhelp_name)
{
	if(!conhelp_name)
		conhelp_name = top.context;

	names = (typeof(conhelp_name) == 'object') ? conhelp_name : [conhelp_name];
	
	msg = '';
	for (i = 0; i < names.length; i++) {
		if (!_c[names[i]] && names[i].indexOf('b_') == 0)	// remove b_ for custom buttons' conhelps
			names[i] = names[i].substr(2);

		msg += (_c[names[i]]) ? _c[names[i]] : names[i];
	}

	return ShowConHelp(msg);
}

function ShowConHelp(conhelp_string)
{
	var prefix = "<div><span class='hint'>";
	var suffix = "</span></div>";
	msg = prefix + conhelp_string + suffix;

	if (is.ns4) {
		if (!top.leftFrame ||
			!top.leftFrame.document ||
			!top.leftFrame.document.layers ||
			!top.leftFrame.document.layers['contexthelp'] ||
			!top.leftFrame.document.layers['contexthelp'].document) {
				top.helpPerm = true;
				return false;
		}
		lyrdoc = top.leftFrame.document.layers['contexthelp'].document;
		lyrdoc.open();
		lyrdoc.write(msg);
		lyrdoc.close();
	}

	if (is.ns5) {
		if (!top.leftFrame ||
			!top.leftFrame.document) {
				top.helpPerm = false;
				return false;
			 }
		lyrdoc = top.leftFrame.document.getElementById('contexthelp');
		if (lyrdoc && lyrdoc.innerHTML)
			lyrdoc.innerHTML = msg;
	}

	if (is.ie) {
		if (!top.leftFrame ||
			!top.leftFrame.document ||
			!top.leftFrame.document.all ||
			!top.leftFrame.document.all['contexthelp'] ||
			!top.leftFrame.document.all['contexthelp'].innerHTML) {
				top.helpPerm = true;
				return false;
		}
		top.leftFrame.document.all['contexthelp'].innerHTML = msg;
	}

	return false;
}
//-->
</script>
</head>
<script language="javascript">
<!--

document.write('<frameset cols="200,*" border=0 framespacing=0 frameborder=0>'+
							 '<frame src="<?=$this->menu_url?>" name="leftFrame" frameborder="0" border="0" noresize="noresize"'+ieAddScroll+ieAddResize+'>'+
							 '<frameset rows="49,*" border="0" frameborder="0" framespacing="0" noresize="noresize">'+
							 '<frame src="ver_pp_frame_top.php" name="topFrame" frameborder=0 border=0 framespacing=0 marginheight=0 marginwidth=0 scrolling="No" noresize>'+
							 '<frame src="ver_pp_frame_main.php<?=$frame_main_args?>" name="contentFrame" frameborder="0" border="0" scrolling="no" onresize="self.contentFrame.setFramesSizes();"/>'+
							 '</frameset></frameset>');

//-->
</script>
<noframes>
<body>
</body>
</noframes>

</html>
<? // **************************************** end of html
	}	
	function drawWrapper( $piUserType = NULL ) {
		global $confixx_skin_dir;
		global $lang_html_charset;
		global $PHP_AUTH_USER;
		global $master_confixx;

		if( $master_confixx != 2 ){
			return $this->draw();
		}
		
		$frame_main_args = "?content_url=$this->content_url";
		$frame_top_args  = "?head_id=$this->head_icon_id&&head_text=$this->head_text";

		$lcServerID = $this->ServerID();

		if( ! is_numeric( $piUserType ) ){
			$piUserType = $_SESSION['_users'][$lcServerID][$PHP_AUTH_USER]['type'];
		}

		switch( $piUserType ){
		case USERTYPE_FTPUSER:
		  $lcPath = 'ftplogin/';
			break;
		case USERTYPE_POPUSER:
		  $lcPath = 'poplogin/';
			break;
		case USERTYPE_USER:
		  $lcPath = 'user/';
			break;
		case USERTYPE_RESELLER:
		  $lcPath = 'reseller/';
			break;
		case USERTYPE_ADMIN:
		  $lcPath = 'admin/';
			break;
		case USERTYPE_MASTER:
		  $lcPath = 'master/';
			break;
		default:
			$lcPath = 'user/';
		}
		$lcPath .= $PHP_AUTH_USER.'/';
		
		$lrId = safe_query( "SELECT confixx_domain FROM admin WHERE server_id='$lcServerID'" );
		list($lcDomain)  = db_fetch_array( $lrId );
		db_free_query( $lrId );

		if( ! $lcDomain ){
			return $this->draw();
		}
		
		$lcPath = "http://$lcDomain/$lcPath".'?wrap=1&SID='.urlencode(session_id());

		if( $DEBUG ){
			echo "GuiPP_MainFrameSet: $lcPath<br>\n";
		}		
		
// ********************************************* html ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
<html>
<head>
<title><?=$this->l_product_name?></title>
<meta http-equiv="Content-Type" content="text/html; charset=<?=$lang_html_charset?>" />
<script language="javascript">
<!--
function setScrollInIE () {
	var navL = self.leftFrame.document.getElementById ('navArea');
	self.leftFrame.document.body.scroll = (navL.clientHeight > self.leftFrame.document.documentElement.clientHeight || navL.clientWidth > self.leftFrame.document.documentElement.clientWidth) ? 'yes' : 'no';
}
ieAddScroll = '';
ieAddResize = '';
isIEdoctype = navigator.appName == 'Microsoft Internet Explorer' && document.documentElement && navigator.userAgent.indexOf ('Opera') == -1;
if (isIEdoctype) {
	ieAddScroll = ' scrolling="no"';
	ieAddResize = ' onresize="setScrollInIE();"';
}

 function openHeadMenuItem (content_url, help_head_key, help_text_key ) {
	 var cnt = parent.parent.contentFrame;
	 if(cnt){
		var url = 'ver_pp_frame_main.php?content_url='+content_url;
		if(help_head_key){
			url += '&help_head_key=' + help_head_key;
		}
		if(help_text_key){
			url += '&help_text_key=' + help_text_key;
		}
		if(cnt.frames['mainFrame']){

			cnt.frames['mainFrame'].location.href = content_url;
			
			if(cnt.frames['helpFrame']){

				var help_url = 'ver_pp_frame_help.php?help_head_key=' +
					help_head_key + '&help_text_key=' + help_text_key;

				cnt.frames['helpFrame'].location.href = help_url;
			}

		}else{
			cnt.location.href = url;
		}
	}

	//	if (parent.parent.mainFrame) {
	//		alert( 'reload mainFrame' );
	//	    parent.parent.mainFrame.location.href = content_url+'&help_url='+help_url;
	//	}
	return false;
}

//var _c = new Array;	// context help messages

//_c['l_ttsquslist_name'] = 'Context help.';

var context = '';
var helpPerm = true;

function mouse_move(context)
{
	if(!top.helpPerm)
		return false;
	top.SetConHelp(context)
}

function SetContext(context)
{
	if (context)
		top.context = context;
	top.SetConHelp();
	return false;
}
// BrowserCheck Object
function BrowserCheck()
{
        var b = navigator.appName
        if (b=='Netscape') this.b = 'ns'
        else if (b=='Microsoft Internet Explorer') this.b = 'ie'
        else this.b = b
        this.version = navigator.appVersion
        this.v = parseInt(this.version)
        this.ns = (this.b=='ns' && this.v>=4)
        this.ns4 = (this.b=='ns' && this.v==4)
        this.ns5 = (this.b=='ns' && this.v==5)
        this.ie = (this.b=='ie' && this.v>=4)
        this.ie4 = (this.version.indexOf('MSIE 4')>0)
        this.ie5 = (this.version.indexOf('MSIE 5')>0)
        this.ie55 = (this.version.indexOf('MSIE 5.5')>0)
        this.min = (this.ns||this.ie)
}

is = new BrowserCheck()

function SetConHelp(conhelp_name)
{
	if(!conhelp_name)
		conhelp_name = top.context;

	names = (typeof(conhelp_name) == 'object') ? conhelp_name : [conhelp_name];
	
	msg = '';
	for (i = 0; i < names.length; i++) {
		if (!_c[names[i]] && names[i].indexOf('b_') == 0)	// remove b_ for custom buttons' conhelps
			names[i] = names[i].substr(2);

		msg += (_c[names[i]]) ? _c[names[i]] : names[i];
	}

	return ShowConHelp(msg);
}

function ShowConHelp(conhelp_string)
{
	var prefix = "<div><span class='hint'>";
	var suffix = "</span></div>";
	msg = prefix + conhelp_string + suffix;

	if (is.ns4) {
		if (!top.leftFrame ||
			!top.leftFrame.document ||
			!top.leftFrame.document.layers ||
			!top.leftFrame.document.layers['contexthelp'] ||
			!top.leftFrame.document.layers['contexthelp'].document) {
				top.helpPerm = true;
				return false;
		}
		lyrdoc = top.leftFrame.document.layers['contexthelp'].document;
		lyrdoc.open();
		lyrdoc.write(msg);
		lyrdoc.close();
	}

	if (is.ns5) {
		if (!top.leftFrame ||
			!top.leftFrame.document) {
				top.helpPerm = false;
				return false;
			 }
		lyrdoc = top.leftFrame.document.getElementById('contexthelp');
		if (lyrdoc && lyrdoc.innerHTML)
			lyrdoc.innerHTML = msg;
	}

	if (is.ie) {
		if (!top.leftFrame ||
			!top.leftFrame.document ||
			!top.leftFrame.document.all ||
			!top.leftFrame.document.all['contexthelp'] ||
			!top.leftFrame.document.all['contexthelp'].innerHTML) {
				top.helpPerm = true;
				return false;
		}
		top.leftFrame.document.all['contexthelp'].innerHTML = msg;
	}

	return false;
}
//-->
</script>
</head>
<script language="javascript">
<!--

document.write('<frameset cols="*" border=0 framespacing=0 frameborder=0>'+
							 '<frame src="<?=$lcPath?>" name="wrapFrame" frameborder="0" border="0" noresize="noresize"'+ieAddScroll+ieAddResize+'>'+
							 '</frameset>');

//-->
</script>
<noframes>
<body>
</body>
</noframes>

</html>
<? // **************************************** end of html
	}	
	
}

// in  ver_pp_frame_top.php
class tGuiPP_FrameTop {
	var $id = 'menu_head_overview';
	var $text = "Header";
	
	function tGuiPP_FrameTop() {
	}
	
	function draw( $poPathBar=NULL) {
		global $confixx_skin_dir;
		global $lang_html_charset;
		
// *********************************** html ?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
	<title></title>
	<meta http-equiv="Content-Type" content="text/html; charset=<?=$lang_html_charset?>"/>
	 <link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/general.css"/>
 	 <link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/images.css"/>
 	 <link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/main/custom.css"/>
 	 <link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/top/custom.css"/>
</head>
<body>
<div class="body">
<?
	 if(is_object($poPathBar)){
		 $poPathBar->draw();
	 }
?>
	</div>

</body>
</html>	
<? // ******************************** end of html
	}	
}

class tGuiPP_FrameMain {

	var $content_url   = "";
	var $help_head_key = "";
	var $help_text_key = "";
	
	function tGuiPP_FrameMain($content_url, $help_head_key, $help_text_key) {
		$this->content_url = $content_url;
		$this->help_head_key = $help_head_key;
		$this->help_text_key = $help_text_key;	
	}
	
	function draw() {
		global $confixx_jscript_dir;
		global $confixx_skin_dir;
		global $lang_html_charset;
		
		$frame_help_args = "?help_head_key=$this->help_head_key&help_text_key=$this->help_text_key";
// *************************************** html ?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
	<title></title>
	<meta http-equiv="Content-Type" content="text/html; charset=<?=$lang_html_charset?>"/>
	<link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/general.css"/>
</head>
<script language="javascript">
<!--
var helpHeight = 20;
var iframeHeight = 0;
var mainFrameHeight = 0;
var mainFrameWidth = 0;
var x,y;
if (self.innerHeight) {// all except Explorer
	x = self.innerWidth;
	y = self.innerHeight;
} else if (document.documentElement && document.documentElement.clientHeight) { // Explorer 6 Strict Mode
	x = document.documentElement.clientWidth;
	y = document.documentElement.clientHeight;
} else if (document.body) { // other Explorers
	x = document.body.clientWidth;
	y = document.body.clientHeight;
}
iframeHeight = y;
mainFrameHeight = y - helpHeight;
mainFrameWidth = x;


//-->
</script>
<script language="javascript" type="text/javascript" src="<?=$confixx_jscript_dir?>ver_xp30_iframessizes.js"></script>
<body onresize="setFramesSizes();" onLoad="setFramesSizes();">

<table border="0" cellspacing="0" cellpadding="0" width="100%">
<tr>
	<td width="100%" id="mainFrameTD"><script language="javascript">
	<!--
document.write ('<iframe width="'+mainFrameWidth+'" height="'+mainFrameHeight+'" name="mainFrame" id="mainFrame" frameborder="0" src="<?=$this->content_url?>" scrolling="yes"></iframe>');
	//-->
	</script></td>
	</tr>
	<tr>
		<td><script language="javascript">
	<!--
document.write ('<iframe width="'+mainFrameWidth+'" height="'+helpHeight+'" name="helpFrame" id="helpFrame" frameborder="0" src="ver_pp_frame_help.php<?=$frame_help_args?>"'+parent.ieAddScroll+'></iframe>');
	//-->
	</script></td>
</tr>
</table>
<script language="javascript">
<!--
//-->
</script>
   </body>
</html>
<? // ************************************ end of html
	}
}

// in ver_xp30_frame_help.php
class tGuiPP_FrameHelp {
	var $l_help_header  = "help";				
	var $l_help_header2 = "Sample help header.";	// todo: locale
	var $l_help_text    = "Sample help text.";	// todo: locale
		
	var $l_hide_help   = "hide help";
	var $l_show_help   = "show help";
	
	
	function tGuiPP_FrameHelp($header, $text)  {
		$this->l_help_header = ltext('help_frame__header');				
		$this->l_hide_help   = ltext('help_frame__hide');
		$this->l_show_help   = ltext('help_frame__show');
		
		$this->l_help_text = $text;
		$this->l_help_header2 = $header;
	}
	
	function draw() {
		global $confixx_jscript_dir;
		global $confixx_skin_dir;
		global $lang_html_charset;

// *************************************** html ?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title></title>
<meta http-equiv="Content-Type" content="text/html; charset=<?=$lang_html_charset?>"/>
<link rel="stylesheet" type="text/css" href="<?=$confixx_skin_dir?>css/help/custom.css"/>

</head>
<script language="javascript">
<!--

//-->
</script>
<body>
<div id="helpArea">
<table border="0" cellspacing="0" cellpadding="0" width="100%">
<tr id="helpHeader" valign="middle">
	<td><img src="<?=$confixx_skin_dir?>images/help.gif" width="16" height="16" border="0" alt="<?=$this->l_help_header?>" align="middle"></td>
	<td id="helpTitle" width="100%"><?=$this->l_help_header?></td>
<td id="helpControls">
<div id="helpHandleShow" style="display:block;"><a href="#" onClick="return parent.setHelpHeight(true);"><?=$this->l_show_help?></a>&nbsp;<a href="#" onClick="return parent.setHelpHeight(true);"><img src="<?=$confixx_skin_dir?>images/show_help.gif" width="11" height="10" border="0" alt="<?=$this->l_show_help?>" align="middle"></a></div>
<div id="helpHandleHide" style="display:none;"><a href="#" onClick="return parent.setHelpHeight(false);"><?=$this->l_hide_help?></a>&nbsp;<a href="#" onClick="return parent.setHelpHeight(false);"><img src="<?=$confixx_skin_dir?>images/hide_help.gif" width="11" height="10" border="0" alt="<?=$this->l_hide_help?>" align="middle"></a></div>
</td></tr>
<tr>
	<td colspan="3"><table border="0" cellspacing="0" cellpadding="0" style="display: none;" id="helpContent" width="100%"><tr><td>


<?=$this->l_help_text?>	
	
	</td></tr></table></td>
</tr>
</table>
<div></div>
<script language="javascript">
<!--
	// fix for the case of recalling help content in opened state
	var helpContent = document.getElementById ('helpContent');
	if (parent.isHelpOpened) {
		parent.setHelpHeight(true);
	}
//-->
</script>
</div>
</body>
</html>
<? // ************************************ end of html
	}
}

?>
